@@ -2,7 +2,7 @@ import inspect
 from dataclasses import dataclass, field
 from typing import Union, Type, Callable, TypeVar, List, Any, Generic
 
-from loguru import logger
+
 from makefun import create_function
 from pinject import binding_keys, locations, SINGLETON
 from pinject.bindings import default_get_arg_names_from_class_name, BindingMapping, new_binding_to_instance
@@ -100,6 +100,7 @@ class ExtendedObjectGraph:
             missings = self._inspect_dependencies(target)
             if missings:
                 for missing in missings:
+                    from loguru import logger
                     logger.error(f"failed to find dependency:{missing}")
                 raise MissingDependencyException.create(missings)
             raise e
@@ -166,7 +167,7 @@ class ExtendedObjectGraph:
         designed = self._providable_to_designed(providable)
         item = Sessioned(self, designed)
         ctx = sessioned_ast_context(self)
-        from pinject_design.di.static_proxy import Object
+        from pinject_design.di.ast import Object
         return DelegatedVar(Object(item), ctx)
 
     def run(self, f):
